@@ -58,7 +58,18 @@ our @EXPORT = qw(
    tcp_connect
 );
 
-our $VERSION = 4.9;
+our $VERSION = 4.91;
+
+# used in cases where we may return immediately but want the
+# caller to do stuff first
+sub _postpone {
+   my ($cb, @args) = @_;
+
+   my $w; $w = AE::timer 0, 0, sub {
+      undef $w;
+      $cb->(@args);
+   };
+}
 
 =item $ipn = parse_ipv4 $dotted_quad
 
@@ -595,7 +606,7 @@ sub resolve_sockaddr($$$$$$) {
    # resolve a records / provide sockaddr structures
    my $resolve = sub {
       my @res;
-      my $cv = AnyEvent->condvar (cb => sub {
+      my $cv = AE::cv {
          $cb->(
             map $_->[2],
             sort {
@@ -604,7 +615,7 @@ sub resolve_sockaddr($$$$$$) {
             }
             @res
          )
-      });
+      };
 
       $cv->begin;
       for my $idx (0 .. $#target) {
@@ -693,14 +704,14 @@ In either case, it will create a list of target hosts (e.g. for multihomed
 hosts or hosts with both IPv4 and IPv6 addresses) and try to connect to
 each in turn.
 
-If the connect is successful, then the C<$connect_cb> will be invoked with
-the socket file handle (in non-blocking mode) as first and the peer host
-(as a textual IP address) and peer port as second and third arguments,
-respectively. The fourth argument is a code reference that you can call
-if, for some reason, you don't like this connection, which will cause
-C<tcp_connect> to try the next one (or call your callback without any
-arguments if there are no more connections). In most cases, you can simply
-ignore this argument.
+After the connection is established, then the C<$connect_cb> will be
+invoked with the socket file handle (in non-blocking mode) as first and
+the peer host (as a textual IP address) and peer port as second and third
+arguments, respectively. The fourth argument is a code reference that you
+can call if, for some reason, you don't like this connection, which will
+cause C<tcp_connect> to try the next one (or call your callback without
+any arguments if there are no more connections). In most cases, you can
+simply ignore this argument.
 
    $cb->($filehandle, $host, $port, $retry)
 
@@ -708,6 +719,10 @@ If the connect is unsuccessful, then the C<$connect_cb> will be invoked
 without any arguments and C<$!> will be set appropriately (with C<ENXIO>
 indicating a DNS resolution failure).
 
+The callback will I<never> be invoked before C<tcp_connect> returns, even
+if C<tcp_connect> was able to connect immediately (e.g. on unix domain
+sockets).
+
 The file handle is perfect for being plugged into L<AnyEvent::Handle>, but
 can be used as a normal perl file handle as well.
 
@@ -809,7 +824,7 @@ sub tcp_connect($$$;$) {
          return unless exists $state{fh};
 
          my $target = shift @target
-            or return (%state = (), $connect->());
+            or return (%state = (), _postpone $connect);
 
          my ($domain, $type, $proto, $sockaddr) = @$target;
 
@@ -823,47 +838,44 @@ sub tcp_connect($$$;$) {
 
          $timeout ||= 30 if AnyEvent::WIN32;
 
-         $state{to} = AnyEvent->timer (after => $timeout, cb => sub {
+         $state{to} = AE::timer $timeout, 0, sub {
             $! = Errno::ETIMEDOUT;
             $state{next}();
-         }) if $timeout;
-
-         # called when the connect was successful, which,
-         # in theory, could be the case immediately (but never is in practise)
-         $state{connected} = sub {
-            # we are connected, or maybe there was an error
-            if (my $sin = getpeername $state{fh}) {
-               my ($port, $host) = unpack_sockaddr $sin;
-
-               delete $state{ww}; delete $state{to};
-
-               my $guard = guard { %state = () };
-
-               $connect->(delete $state{fh}, format_address $host, $port, sub {
-                  $guard->cancel;
-                  $state{next}();
-               });
-            } else {
-               # dummy read to fetch real error code
-               sysread $state{fh}, my $buf, 1 if $! == Errno::ENOTCONN;
-
-               return if $! == Errno::EAGAIN; # skip spurious wake-ups
-
-               delete $state{ww}; delete $state{to};
-
-               $state{next}();
-            }
-         };
+         } if $timeout;
 
          # now connect       
-         if (connect $state{fh}, $sockaddr) {
-            $state{connected}->();
-         } elsif ($! == Errno::EINPROGRESS # POSIX
-                  || $! == Errno::EWOULDBLOCK
-                  # WSAEINPROGRESS intentionally not checked - it means something else entirely
-                  || $! == AnyEvent::Util::WSAEINVAL # not convinced, but doesn't hurt
-                  || $! == AnyEvent::Util::WSAEWOULDBLOCK) {
-            $state{ww} = AnyEvent->io (fh => $state{fh}, poll => 'w', cb => $state{connected});
+         if (
+            (connect $state{fh}, $sockaddr)
+            || ($! == Errno::EINPROGRESS # POSIX
+                || $! == Errno::EWOULDBLOCK
+                # WSAEINPROGRESS intentionally not checked - it means something else entirely
+                || $! == AnyEvent::Util::WSAEINVAL # not convinced, but doesn't hurt
+                || $! == AnyEvent::Util::WSAEWOULDBLOCK)
+         ) {
+            $state{ww} = AE::io $state{fh}, 1, sub {
+               # we are connected, or maybe there was an error
+               if (my $sin = getpeername $state{fh}) {
+                  my ($port, $host) = unpack_sockaddr $sin;
+
+                  delete $state{ww}; delete $state{to};
+
+                  my $guard = guard { %state = () };
+
+                  $connect->(delete $state{fh}, format_address $host, $port, sub {
+                     $guard->cancel;
+                     $state{next}();
+                  });
+               } else {
+                  # dummy read to fetch real error code
+                  sysread $state{fh}, my $buf, 1 if $! == Errno::ENOTCONN;
+
+                  return if $! == Errno::EAGAIN; # skip spurious wake-ups
+
+                  delete $state{ww}; delete $state{to};
+
+                  $state{next}();
+               }
+            };
          } else {
             $state{next}();
          }
@@ -997,7 +1009,7 @@ sub tcp_server($$$;$) {
    listen $state{fh}, $len
       or Carp::croak "listen: $!";
 
-   $state{aw} = AnyEvent->io (fh => $state{fh}, poll => 'r', cb => sub {
+   $state{aw} = AE::io $state{fh}, 0, sub {
       # this closure keeps $state alive
       while (my $peer = accept my $fh, $state{fh}) {
          fh_nonblocking $fh, 1; # POSIX requires inheritance, the outside world does not
@@ -1005,7 +1017,7 @@ sub tcp_server($$$;$) {
          my ($service, $host) = unpack_sockaddr $peer;
          $accept->($fh, format_address $host, $service);
       }
-   });
+   };
 
    defined wantarray
       ? guard { %state = () } # clear fh and watcher, which breaks the circular dependency
